#include <gtkmm/window.h>
#include <gtkmm/button.h>
#include <gtkmm/box.h>
#include <gtkmm/scrolledwindow.h>

#include "Sutu3Win.h"


const char *CAPTION_STEP       = "Step";
const char *CAPTION_RESET      = "Reset";



Sutu3Win::Sutu3Win()
    : m_HBox0(false, 5),
      m_VBox1(false, 5),
      m_butStep(CAPTION_STEP),
      m_butReset(CAPTION_RESET),
      m_pSS(NULL),
      m_iFirstRand(-1) {
  
    m_butStep.signal_clicked().connect(sigc::mem_fun(*this, &Sutu3Win::step_action) );
    m_butReset.signal_clicked().connect(sigc::mem_fun(*this, &Sutu3Win::reset_action) );
  
    m_VBox1.pack_start(m_butStep,      Gtk::PACK_EXPAND_WIDGET,5);
    m_VBox1.pack_start(m_butReset,     Gtk::PACK_EXPAND_WIDGET,5);

    m_VBox1.pack_start(m_txtW, Gtk::PACK_SHRINK,5);

    m_HBox0.pack_start(m_scrW,   Gtk::PACK_EXPAND_WIDGET,5);
    m_HBox0.pack_start(m_VBox1,  Gtk::PACK_SHRINK,5);

    add(m_HBox0);
    
    show_all_children();
  
    m_butStep.set_sensitive(false);
}

//---------------------------------------------------------------------------
// destructor
//
Sutu3Win::~Sutu3Win() {
    if (m_pSS != NULL) {
        delete m_pSS;
    }
}




//-----------------------------------------------------------------------------
// reset_action
//   callback for reset action
//   -create a new SutuSystem from the parameters in the dialog
//
void Sutu3Win::reset_action() {
    // set original concentration (which has to be stored somewhere)
    if (m_pSS != NULL) {
        delete m_pSS;
    }

    int iRandSeed = 12343271;
    
    printf("using randseed %d\n", iRandSeed);
    srand(iRandSeed);
    m_iFirstRand = rand();
    printf("Sutu3Win:   %d\n", m_iFirstRand);
    
    m_pSS = new SutuSystem(12343271);
    
    // change sensitivities
    m_butReset.set_sensitive(true);
    m_butStep.set_sensitive(true);
 
}

//-----------------------------------------------------------------------------
// step_action
//   callback for reset action
//
void Sutu3Win::step_action() {
    m_pSS->step(m_iFirstRand);
}

